@@ -28,15 +28,13 @@ PERFORMANCE OF THIS SOFTWARE.
 
 #include "pymemcompat.h"
 #include "structmember.h"
-#if defined(_WIN32) || defined(_WIN64) || defined(__WIN32__) || defined(WIN32) || defined(MS_WIN32)
+#if defined(MS_WINDOWS)
+#include <winsock2.h>
 #include <windows.h>
 #include <config-win.h>
 #else
 #include "my_config.h"
 #endif
-#ifndef uint
-#define uint unsigned int
-#endif
 #include "mysql.h"
 #include "mysqld_error.h"
 #include "errmsg.h"
@@ -418,12 +416,14 @@ _mysql_ResultObject_Initialize(
 					if (PyInt_Check(pmask)) {
 						mask = PyInt_AS_LONG(pmask);
 						if (mask & fields[i].flags) {
+							Py_DECREF(t);
 							break;
 						}
 						else {
-							continue;
+							goto cleanup;
 						}
 					} else {
+						Py_DECREF(t);
 						break;
 					}
 				}
@@ -481,8 +481,8 @@ _mysql_ConnectionObject_Initialize(
 #endif
 	char *host = NULL, *user = NULL, *passwd = NULL,
 		*db = NULL, *unix_socket = NULL;
-	uint port = MYSQL_PORT;
-	uint client_flag = 0;
+	unsigned int port = 0;
+	unsigned int client_flag = 0;
 	static char *kwlist[] = { "host", "user", "passwd", "db", "port",
 				  "unix_socket", "conv",
 				  "connect_timeout", "compress",
@@ -509,24 +509,15 @@ _mysql_ConnectionObject_Initialize(
 					 &init_command, &read_default_file,
 					 &read_default_group,
 					 &client_flag, &ssl,
-					 &local_infile
+					 &local_infile /* DO NOT PATCH FOR RECONNECT, IDIOTS
+					 IF YOU DO THIS, I WILL NOT SUPPORT YOUR PACKAGES. */
 					 ))
 		return -1;
 
-	if (!conv) 
-		conv = PyDict_New();
-#if PY_VERSION_HEX > 0x02000100
-	else
-		Py_INCREF(conv);
-#endif
-	if (!conv)
-		return -1;
-	self->converter = conv;
-
 #define _stringsuck(d,t,s) {t=PyMapping_GetItemString(s,#d);\
         if(t){d=PyString_AsString(t);Py_DECREF(t);}\
         PyErr_Clear();}
-	
+
 	if (ssl) {
 #if HAVE_OPENSSL
 		PyObject *value = NULL;
@@ -580,6 +571,17 @@ _mysql_ConnectionObject_Initialize(
 		_mysql_Exception(self);
 		return -1;
 	}
+
+        /* Internal references to python-land objects */
+	if (!conv)
+		conv = PyDict_New();
+	else
+		Py_INCREF(conv);
+
+	if (!conv)
+		return -1;
+	self->converter = conv;
+
 	/*
 	  PyType_GenericAlloc() automatically sets up GC allocation and
 	  tracking for GC objects, at least in 2.2.1, so it does not need to
@@ -1713,7 +1715,7 @@ _mysql_ConnectionObject_kill(
 {
 	unsigned long pid;
 	int r;
-	if (!PyArg_ParseTuple(args, "i:kill", &pid)) return NULL;
+	if (!PyArg_ParseTuple(args, "k:kill", &pid)) return NULL;
 	check_connection(self);
 	Py_BEGIN_ALLOW_THREADS
 	r = mysql_kill(&(self->connection), pid);
